@@ -13,7 +13,9 @@ use Perinci::Object;
 use Perinci::ToUtil;
 use Scalar::Util qw(reftype blessed);
 
-our $VERSION = '1.03'; # VERSION
+our $VERSION = '1.04'; # VERSION
+
+our $REQ_VERSION = 0; # version requested by user
 
 with 'SHARYANTO::Role::ColorTheme' unless $ENV{COMP_LINE};
 #with 'SHARYANTO::Role::TermAttrs' unless $ENV{COMP_LINE}; already loaded by ColorTheme
@@ -149,6 +151,33 @@ has common_opts => (
             },
         };
 
+        if ($REQ_VERSION >= 1.04) {
+            $opts{json} = {
+                getopt  => "json",
+                summary => N__("Equivalent to --format=json-pretty"),
+                handler => sub {
+                    $self->format_set(1);
+                    $self->format('json-pretty');
+                },
+            };
+            $opts{yaml} = {
+                getopt  => "yaml",
+                summary => N__("Equivalent to --format=yaml"),
+                handler => sub {
+                    $self->format_set(1);
+                    $self->format('yaml');
+                },
+            };
+            $opts{perl} = {
+                getopt  => "perl",
+                summary => N__("Equivalent to --format=perl"),
+                handler => sub {
+                    $self->format_set(1);
+                    $self->format('perl');
+                },
+            };
+        }
+
         $opts{format_options} = {
             getopt  => "format-options=s",
             summary => N__("Pass options to formatter"),
@@ -308,6 +337,11 @@ has action_metadata => (
     },
 );
 
+sub VERSION {
+    my ($pkg, $req) = @_;
+    $REQ_VERSION = $req;
+}
+
 sub __json_decode {
     require JSON;
     state $json = do { JSON->new->allow_nonref };
@@ -1789,7 +1823,7 @@ Perinci::CmdLine - Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 SYNOPSIS
 
@@ -1798,7 +1832,7 @@ In your command-line script:
  #!/usr/bin/perl
  use 5.010;
  use Log::Any '$log';
- use Perinci::CmdLine;
+ use Perinci::CmdLine 1.04;
 
  our %SPEC;
  $SPEC{foo} = {
@@ -1906,7 +1940,7 @@ etc) can be renamed or disabled.
 This module uses L<Log::Any> and L<Log::Any::App> for logging. This module uses
 L<Moo> for OO.
 
-=for Pod::Coverage ^(BUILD|run_.+|help_section_.+|format_result|format_row|display_result|get_subcommand|list_subcommands|parse_common_opts|parse_subcommand_opts|format_set|format_options|format_options_set)$
+=for Pod::Coverage ^(VERSION|BUILD|run_.+|help_section_.+|format_result|format_row|display_result|get_subcommand|list_subcommands|parse_common_opts|parse_subcommand_opts|format_set|format_options|format_options_set)$
 
 =head1 DISPATCHING
 
@@ -2302,11 +2336,13 @@ A partial example from the default set by the framework:
 
 The default contains: help (getopt C<help|h|?>), version (getopt C<version|v>),
 action (getopt C<action>), format (getopt C<format=s>), format_options (getopt
-C<format-options=s>). If there are more than one subcommands, this will also be
-added: list (getopt C<list|l>). If dry-run is supported by function, there will
-also be: dry_run (getopt C<dry-run>). If undo is turned on, there will also be:
-undo (getopt C<undo>), redo (getopt C<redo>), history (getopt C<history>),
-clear_history (getopt C<clear-history>).
+C<format-options=s>), json*, yaml*, perl*. If there are more than one
+subcommands, this will also be added: list (getopt C<list|l>). If dry-run is
+supported by function, there will also be: dry_run (getopt C<dry-run>). If undo
+is turned on, there will also be: undo (getopt C<undo>), redo (getopt C<redo>),
+history (getopt C<history>), clear_history (getopt C<clear-history>).
+
+*) Currently only added if you say C<use Perinci::CmdLine 1.04>.
 
 Sometimes you do not want some options, e.g. to remove C<format> and
 C<format_options>:
